@@ -11,7 +11,7 @@ from shortuuid.main import *
 
 class LegacyShortUUIDTest(unittest.TestCase):
     def test_generation(self):
-        self.assertTrue(20 < len(uuid()), 24)
+        self.assertTrue(20 < len(uuid()) < 24)
         self.assertTrue(20 < len(uuid("http://www.example.com/")) < 24)
         self.assertTrue(20 < len(uuid("HTTP://www.example.com/")) < 24)
         self.assertTrue(20 < len(uuid("example.com/")) < 24)
@@ -67,6 +67,10 @@ class ClassShortUUIDTest(unittest.TestCase):
         u = UUID('{12345678-1234-5678-1234-567812345678}')
         self.assertEquals(su.decode("VoVuUtBhZ6TvQSAYEqNdF5"), u)
 
+    def test_random(self):
+        su = ShortUUID()
+        self.assertEquals(len(su.random()), 22)
+
     def test_alphabet(self):
         alphabet = "01"
         su1 = ShortUUID(alphabet)
